( cd usr/bin ; rm -rf f77 )
( cd usr/bin ; ln -sf g77 f77 )
( cd usr/bin ; rm -rf g77 )
( cd usr/bin ; ln -sf g77-gcc-3.2.3 g77 )
( cd usr/lib ; rm -rf libg2c.so.0 )
( cd usr/lib ; ln -sf libg2c.so.0.0.0 libg2c.so.0 )
( cd usr/lib ; rm -rf libg2c.so )
( cd usr/lib ; ln -sf libg2c.so.0.0.0 libg2c.so )
( cd usr/man/man1 ; rm -rf f77.1.gz )
( cd usr/man/man1 ; ln -sf g77.1.gz f77.1.gz )
